This is the mail archive of the glibc-cvs@sourceware.org mailing list for the glibc project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

GNU C Library master sources branch master updated. glibc-2.20-14-g5379aeb


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GNU C Library master sources".

The branch, master has been updated
       via  5379aebddd0a35c052e7149fb4ff88b49676516e (commit)
      from  8c0ab919f63dc03a420751172602a52d2bea59a8 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://sourceware.org/git/gitweb.cgi?p=glibc.git;a=commitdiff;h=5379aebddd0a35c052e7149fb4ff88b49676516e

commit 5379aebddd0a35c052e7149fb4ff88b49676516e
Author: Siddhesh Poyarekar <siddhesh@redhat.com>
Date:   Fri Sep 12 12:31:05 2014 +0530

    Enhance tst-xmmymm.sh to detect zmm register usage in ld.so (BZ #16194)
    
    2d63a517e4084ec80403cd9f278690fa8b676cc4 added support to save and
    restore zmm register in the dynamic linker, but did not enhance
    test-xmmymm.sh to detect accidental usage of these registers.  The
    patch below adds that check.
    
    The script has also been renamed to tst-ld-sse-use.sh.  To see the
    minimal changes, run `git show -M`.
    
    	[BZ #16194]
    	* sysdeps/x86/tst-xmmymm.sh: Rename file to...
    	* sysdeps/x86/tst-ld-sse-use.sh: ... this.  Check for zmm
    	register usage.
    	* sysdeps/x86/Makefile: Adjust.

diff --git a/ChangeLog b/ChangeLog
index d528cab..7a3346a 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,11 @@
+2014-09-12  Siddhesh Poyarekar  <siddhesh@redhat.com>
+
+	[BZ #16194]
+	* sysdeps/x86/tst-xmmymm.sh: Rename file to...
+	* sysdeps/x86/tst-ld-sse-use.sh: ... this.  Check for zmm
+	register usage.
+	* sysdeps/x86/Makefile: Adjust.
+
 2014-09-11  Kostya Serebryany  <konstantin.s.serebryany@gmail.com>
 	    Roland McGrath  <roland@hack.frob.com>
 
diff --git a/sysdeps/x86/Makefile b/sysdeps/x86/Makefile
index a96c8bd..087bbde 100644
--- a/sysdeps/x86/Makefile
+++ b/sysdeps/x86/Makefile
@@ -2,8 +2,8 @@ ifeq ($(subdir),elf)
 CFLAGS-.os += $(if $(filter $(@F),$(patsubst %,%.os,$(all-rtld-routines))),\
 		   -mno-sse -mno-mmx)
 
-tests-special += $(objpfx)tst-xmmymm.out
-$(objpfx)tst-xmmymm.out: ../sysdeps/x86/tst-xmmymm.sh $(objpfx)ld.so
+tests-special += $(objpfx)tst-ld-sse-use.out
+$(objpfx)tst-ld-sse-use.out: ../sysdeps/x86/tst-ld-sse-use.sh $(objpfx)ld.so
 	@echo "Checking ld.so for SSE register use.  This will take a few seconds..."
 	$(SHELL) $< $(objpfx) '$(NM)' '$(OBJDUMP)' '$(READELF)' > $@; \
 	$(evaluate-test)
diff --git a/sysdeps/x86/tst-xmmymm.sh b/sysdeps/x86/tst-ld-sse-use.sh
similarity index 90%
rename from sysdeps/x86/tst-xmmymm.sh
rename to sysdeps/x86/tst-ld-sse-use.sh
index 69ddb58..c707ca9 100755
--- a/sysdeps/x86/tst-xmmymm.sh
+++ b/sysdeps/x86/tst-ld-sse-use.sh
@@ -1,5 +1,5 @@
 #! /bin/bash
 # Make sure no code in ld.so uses xmm/ymm registers on x86-64.
 # Copyright (C) 2009-2014 Free Software Foundation, Inc.
 # This file is part of the GNU C Library.
 
@@ -24,7 +24,7 @@ NM="$2"
 OBJDUMP="$3"
 READELF="$4"
 
-tmp=$(mktemp ${objpfx}tst-xmmymm.XXXXXX)
+tmp=$(mktemp ${objpfx}tst-ld-sse-use.XXXXXX)
 trap 'rm -f "$tmp"' 1 2 3 15
 
 # List of object files we have to test
@@ -80,12 +80,12 @@ echo "object files needed: $tocheck"
 cp /dev/null "$tmp"
 for f in $tocheck; do
   $OBJDUMP -d "$objpfx"../*/"$f" |
-  awk 'BEGIN { last="" } /^[[:xdigit:]]* <[_[:alnum:]]*>:$/ { fct=substr($2, 2, length($2)-3) } /,%[xy]mm[[:digit:]]*$/ { if (last != fct) { print fct; last=fct} }' |
+  awk 'BEGIN { last="" } /^[[:xdigit:]]* <[_[:alnum:]]*>:$/ { fct=substr($2, 2, length($2)-3) } /,%[xyz]mm[[:digit:]]*$/ { if (last != fct) { print fct; last=fct} }' |
   while read fct; do
     if test "$fct" = "_dl_runtime_profile" -o "$fct" = "_dl_x86_64_restore_sse"; then
       continue;
     fi
-    echo "function $fct in $f modifies xmm/ymm" >> "$tmp"
+    echo "function $fct in $f modifies xmm/ymm/zmm" >> "$tmp"
     result=1
   done
 done

-----------------------------------------------------------------------

Summary of changes:
 ChangeLog                                        |    8 ++++++++
@@ -1,5 +1,5 @@
 #! /bin/bash
-# Make sure no code in ld.so uses xmm/ymm registers on x86-64.
+# Make sure no code in ld.so uses xmm/ymm/zmm registers on x86-64.
 # Copyright (C) 2009-2014 Free Software Foundation, Inc.
 # This file is part of the GNU C Library.
 sysdeps/x86/Makefile                             |    4 ++--
 sysdeps/x86/{tst-xmmymm.sh => tst-ld-sse-use.sh} |    8 ++++----
 3 files changed, 14 insertions(+), 6 deletions(-)
 rename sysdeps/x86/{tst-xmmymm.sh => tst-ld-sse-use.sh} (90%)


hooks/post-receive
-- 
GNU C Library master sources


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]